@@ -100,7 +100,7 @@ void InflectionWidget::setWordType()
         return;
     }
 
-    KEduVocWordType *container = 0;
+    KEduVocWordType *container = nullptr;
 
     if (sender()->objectName() == QLatin1String("toVerb")) {
         container = m_doc->wordTypeContainer()->childOfType(KEduVocWordFlag::Verb);
@@ -142,3 +142,5 @@ void InflectionWidget::setWordType()
         setTranslation(m_entry, m_translation);
     }
 }
+
+#include "moc_inflectionwidget.cpp"
